==> huaweicloudsdkdws-3.1.131-py2.py3-none-any.whl: huaweicloudsdkdws/v2/model/copy_snapshot_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CopySnapshotRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'snapshot_id': 'str',
        'body': 'LinkCopyReq'
    }

    attribute_map = {
        'snapshot_id': 'snapshot_id',
        'body': 'body'
    }

    def __init__(self, snapshot_id=None, body=None):
        """CopySnapshotRequest

        The model defined in huaweicloud sdk

        :param snapshot_id: 快照ID
        :type snapshot_id: str
        :param body: Body of the CopySnapshotRequest
        :type body: :class:`huaweicloudsdkdws.v2.LinkCopyReq`
        """
        
        

        self._snapshot_id = None
        self._body = None
        self.discriminator = None

        self.snapshot_id = snapshot_id
        if body is not None:
            self.body = body

    @property
    def snapshot_id(self):
        """Gets the snapshot_id of this CopySnapshotRequest.

        快照ID

        :return: The snapshot_id of this CopySnapshotRequest.
        :rtype: str
        """
        return self._snapshot_id

    @snapshot_id.setter
    def snapshot_id(self, snapshot_id):
        """Sets the snapshot_id of this CopySnapshotRequest.

        快照ID

        :param snapshot_id: The snapshot_id of this CopySnapshotRequest.
        :type snapshot_id: str
        """
        self._snapshot_id = snapshot_id

    @property
    def body(self):
        """Gets the body of this CopySnapshotRequest.

        :return: The body of this CopySnapshotRequest.
        :rtype: :class:`huaweicloudsdkdws.v2.LinkCopyReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this CopySnapshotRequest.

        :param body: The body of this CopySnapshotRequest.
        :type body: :class:`huaweicloudsdkdws.v2.LinkCopyReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CopySnapshotRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdws-3.1.148-py2.py3-none-any.whl: huaweicloudsdkdws/v2/model/copy_snapshot_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CopySnapshotRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'snapshot_id': 'str',
        'body': 'LinkCopyReq'
    }

    attribute_map = {
        'snapshot_id': 'snapshot_id',
        'body': 'body'
    }

    def __init__(self, snapshot_id=None, body=None):
        r"""CopySnapshotRequest

        The model defined in huaweicloud sdk

        :param snapshot_id: 快照ID
        :type snapshot_id: str
        :param body: Body of the CopySnapshotRequest
        :type body: :class:`huaweicloudsdkdws.v2.LinkCopyReq`
        """
        
        

        self._snapshot_id = None
        self._body = None
        self.discriminator = None

        self.snapshot_id = snapshot_id
        if body is not None:
            self.body = body

    @property
    def snapshot_id(self):
        r"""Gets the snapshot_id of this CopySnapshotRequest.

        快照ID

        :return: The snapshot_id of this CopySnapshotRequest.
        :rtype: str
        """
        return self._snapshot_id

    @snapshot_id.setter
    def snapshot_id(self, snapshot_id):
        r"""Sets the snapshot_id of this CopySnapshotRequest.

        快照ID

        :param snapshot_id: The snapshot_id of this CopySnapshotRequest.
        :type snapshot_id: str
        """
        self._snapshot_id = snapshot_id

    @property
    def body(self):
        r"""Gets the body of this CopySnapshotRequest.

        :return: The body of this CopySnapshotRequest.
        :rtype: :class:`huaweicloudsdkdws.v2.LinkCopyReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this CopySnapshotRequest.

        :param body: The body of this CopySnapshotRequest.
        :type body: :class:`huaweicloudsdkdws.v2.LinkCopyReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CopySnapshotRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
